@@ -306,6 +306,10 @@ class SolgemaFullcalendarJS(BrowserView):
         else:
             return '/'+self.context.absolute_url(relative=1)
 
+    def __call__(self):
+        self.request.RESPONSE.setHeader('Content-Type','application/x-javascript; charset=utf-8')
+        return super(SolgemaFullcalendarJS, self).__call__()
+
 class SolgemaFullcalendarEvents(BrowserView):
     """Solgema Fullcalendar Update browser view"""
 
@@ -366,8 +370,8 @@ class SolgemaFullcalendarEvents(BrowserView):
             user = pm.getAuthenticatedMember()
             if user and user.has_permission('Modify portal content', self.context):
                 del args['review_state']
-        catalog = getToolByName(context, 'portal_catalog')
-        brains = catalog.searchResults(**args)
+        searchMethod = getMultiAdapter((self.context,), ISolgemaFullcalendarCatalogSearch)
+        brains = searchMethod.searchResults(args)
 
         for filt in filters:
             if isinstance(filt['values'], str):
