@@ -4,6 +4,7 @@ from AccessControl.PermissionRole import rolesForPermissionOn
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.CatalogTool import _mergedLocalRoles
 from interfaces import ISFBaseEventFields
+from zope.annotation.interfaces import IAttributeAnnotatable
 
 @indexer(Interface)
 def SFAllowedRolesAndUsersModify(obj):
@@ -27,7 +28,7 @@ def SFAllowedRolesAndUsersModify(obj):
         del allowed['Owner']
     return list(allowed.keys())
 
-@indexer(Interface)
+@indexer(IAttributeAnnotatable)
 def SFAllDay(obj):
     adapted = ISFBaseEventFields(obj, None)
     if adapted is not None:
