@@ -5,6 +5,12 @@ from Solgema.fullcalendar.config import PRODUCT_DEPENDENCIES
 def doNothing(context):
     pass
 
+def updateRegistries(context):
+    jstool = getToolByName(context, 'portal_javascripts')
+    jstool.cookResources()
+    csstool = getToolByName(context, 'portal_css')
+    csstool.cookResources()
+
 def upgrade03(context):
     portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
     portal_setup = getToolByName(context, 'portal_setup')
@@ -26,10 +32,7 @@ def upgrade11(context):
             portal_quickinstaller.installProduct(product)
             transaction.savepoint()
 
-    jstool = getToolByName(context, 'portal_javascripts')
-    jstool.cookResources()
-    csstool = getToolByName(context, 'portal_css')
-    csstool.cookResources()
+    updateRegistries(context)
 
 def upgrade12(context):
     portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
@@ -37,10 +40,7 @@ def upgrade12(context):
 
     portal_setup.runAllImportStepsFromProfile('profile-Solgema.fullcalendar:upgrade12', purge_old=False)
 
-    jstool = getToolByName(context, 'portal_javascripts')
-    jstool.cookResources()
-    csstool = getToolByName(context, 'portal_css')
-    csstool.cookResources()
+    updateRegistries(context)
 
 def upgrade13(context):
     portal_quickinstaller = getToolByName(context, 'portal_quickinstaller')
@@ -48,11 +48,17 @@ def upgrade13(context):
 
     portal_setup.runAllImportStepsFromProfile('profile-Solgema.fullcalendar:upgrade13', purge_old=False)
 
-    jstool = getToolByName(context, 'portal_javascripts')
-    jstool.cookResources()
-    csstool = getToolByName(context, 'portal_css')
-    csstool.cookResources()
+    updateRegistries(context)
 
 def upgrade14(context):
-    jstool = getToolByName(context, 'portal_javascripts')
-    jstool.cookResources()
+    updateRegistries(context)
+
+def upgrade16(context):
+    #be sure solgemafullcalendar_view is installed
+    ttool = getToolByName(context, 'portal_types')
+    topic_type = ttool.Topic
+    topic_methods = topic_type.view_methods
+    if 'solgemafullcalendar_view' not in topic_methods:
+        topic_type.manage_changeProperties(view_methods=topic_methods+tuple(['solgemafullcalendar_view',]))
+    updateRegistries(context)
+
